@@ -1,6 +1,7 @@
 SELECT mimetype,
        oneshot,
-       DATA
+       sha256sum,
+       data
 FROM stor
 WHERE id=:id
   AND fname=:fname
